Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(193)

Unified Diff: net/reporting/reporting_context.h

Issue 2889193002: Reporting: Add ReportingDelegate to check site permissions (Closed)
Patch Set: rebase, tweak, format Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « net/BUILD.gn ('k') | net/reporting/reporting_context.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: net/reporting/reporting_context.h
diff --git a/net/reporting/reporting_context.h b/net/reporting/reporting_context.h
index f24fc2d7b254688818070968af97e5149b03fbeb..c3517daefbe8935d3af12e28ac0db2b8ff2a5ab9 100644
--- a/net/reporting/reporting_context.h
+++ b/net/reporting/reporting_context.h
@@ -22,6 +22,7 @@ namespace net {
class ReportingBrowsingDataRemover;
class ReportingCache;
+class ReportingDelegate;
class ReportingDeliveryAgent;
class ReportingEndpointManager;
class ReportingGarbageCollector;
@@ -47,6 +48,7 @@ class NET_EXPORT ReportingContext {
base::TickClock* tick_clock() { return tick_clock_.get(); }
ReportingUploader* uploader() { return uploader_.get(); }
+ ReportingDelegate* delegate() { return delegate_.get(); }
ReportingCache* cache() { return cache_.get(); }
ReportingEndpointManager* endpoint_manager() {
return endpoint_manager_.get();
@@ -81,13 +83,15 @@ class NET_EXPORT ReportingContext {
base::ObserverList<ReportingObserver, /* check_empty= */ true> observers_;
+ std::unique_ptr<ReportingDelegate> delegate_;
+
std::unique_ptr<ReportingCache> cache_;
// |endpoint_manager_| must come after |tick_clock_| and |cache_|.
std::unique_ptr<ReportingEndpointManager> endpoint_manager_;
// |delivery_agent_| must come after |tick_clock_|, |uploader_|, |cache_|,
// and |endpoint_manager_|.
std::unique_ptr<ReportingDeliveryAgent> delivery_agent_;
// |persister_| must come after |clock_|, |tick_clock_|, and |cache_|.
« no previous file with comments | « net/BUILD.gn ('k') | net/reporting/reporting_context.cc » ('j') | no next file with comments »
@@ -81,13 +83,15 @@ class NET_EXPORT ReportingContext {
// |endpoint_manager_| must come after |tick_clock_| and |cache_|.
std::unique_ptr<ReportingEndpointManager> endpoint_manager_;
- // |delivery_agent_| must come after |tick_clock_|, |uploader_|, |cache_|,
- // and |endpoint_manager_|.
+ // |delivery_agent_| must come after |tick_clock_|, |delegate_|, |uploader_|,
+ // |cache_|, and |endpoint_manager_|.
std::unique_ptr<ReportingDeliveryAgent> delivery_agent_;
// |persister_| must come after |clock_|, |tick_clock_|, and |cache_|.

Powered by Google App Engine
This is Rietveld 408576698